# Changing Options

From the Options dialog, you can change the various display options of Windows Git.

## General Options

Borders between windows
If selected, windows that the game opens in the main interpreter window are surrounded by a standard window border.

Enable menus, toolbars and the status bar
If selected, the interpreter window has a menu bar, a toolbar and a status bar. If not selected, these items are not present. In either case, the options dialog is still always accessible from the system menu (that is, the menu obtained by clicking on the icon in the left corner of the interpreter's title bar).

Style hints override user settings
If selected, style hints set by the game override any style options selected by the user. The style options are described below.

Use a custom hyperlink colour
If selected, hyperlinks are displayed using the colour set by the colour chooser button to the right of this option.

Underline hyperlinks
If selected, hyperlinks are displayed underlined, as in most web browsers.

If the game has an iFiction record ...
When Windows Git loads a game that contains an iFiction record, it may show the About This Game dialog. This option determines whether the dialog is never shown, only shown the first time, or shown every time.

## Style Options

Note that changing the values discussed below will only affect new windows opened by the game, not any existing ones. Furthermore, if the game overrides any of these settings with style hints, then that particular style will not be editable.

Window
Determines the type of window for which the style is being edited. Text buffer windows are the normal windows in which output appears in the proportional font and the user enters input. Text grid windows always show text in a fixed width font and are used for tasks such as a status bar. Only some of the style options are relevant for text grid windows; the remainder are greyed out.

Style
Determines the particular style being edited.

Indentation
How much a paragraph in this style is indented, in arbitrary units.

Paragraph Indentation
How much the first line of a paragraph in this style is indented, in arbitrary units.

Justification
Whether paragraphs are drawn flush with the left margin, the right margin, both margins, or centered.

Text Size
The size of the text, measured in arbitrary units, relative to the default size determined by the user using the font dialogs from the menu or toolbar.

Text Weight
Whether the text is drawn normally, emphasized, or lightly.

Italic
If selected, text is drawn italicised.

Proportional
If selected, text is drawn using the proportional font. If not selected, the fixed-width font is used instead.

Reverse
If selected, text is drawn reversed, i.e. the background colour is used to draw the text, with the background set to the text colour.

Text Colour
The colour in which the text is drawn in.

Background
The colour in which the background behind the text is drawn.

## Speech Options

Windows Git can use Microsoft's Speech Engine 5 to speak text, which is present by default in Windows XP and later. If it is present, there is a Speech tab in in the options dialog, containing controls that allow speaking of the game's text to be turned on, and the voice and speed at which it is spoken in to be set.